@@ -302,10 +302,6 @@ void EvolutionContactSource::readItem(const string &luid, std::string &item, boo
         throwError(string("reading contact ") + luid,
                    gerror);
     }
-#ifdef ENABLE_MAEMO
-    // load detached photos etc
-    e_contact_inline_data(contact);
-#endif
     eptr<EContact, GObject> contactptr(contact, "contact");
     eptr<char> vcardstr(e_vcard_to_string(&contactptr->parent,
                                           EVC_FORMAT_VCARD_30));
@@ -334,7 +330,7 @@ EvolutionContactSource::insertItem(const string &uid, const std::string &item, b
                 throwError("no UID for contact");
             }
             string newrev = getRevision(newuid);
-            return InsertItemResult(newuid, newrev, false);
+            return InsertItemResult(newuid, newrev, ITEM_OKAY);
         } else {
             throwError(uid.empty() ?
                        "storing new contact" :
@@ -345,7 +341,7 @@ EvolutionContactSource::insertItem(const string &uid, const std::string &item, b
         throwError(string("failure parsing vcard " ) + item);
     }
     // not reached!
-    return InsertItemResult("", "", false);
+    return InsertItemResult("", "", ITEM_OKAY);
 }
 
 void EvolutionContactSource::removeItem(const string &uid)
