@@ -25,6 +25,22 @@ static std::string SubIDName(const std::string &subid)
     return subid.empty() ? "<master>" : subid;
 }
 
+/** remove X-SYNCEVOLUTION-EXDATE-DETACHED from VEVENT */
+static void removeSyncEvolutionExdateDetached(icalcomponent *parent)
+{
+    icalproperty *prop = icalcomponent_get_first_property(parent, ICAL_ANY_PROPERTY);
+    while (prop) {
+        icalproperty *next = icalcomponent_get_next_property(parent, ICAL_ANY_PROPERTY);
+        const char *xname = icalproperty_get_x_name(prop);
+        if (xname &&
+            !strcmp(xname, "X-SYNCEVOLUTION-EXDATE-DETACHED")) {
+            icalcomponent_remove_property(parent, prop);
+            icalproperty_free(prop);
+        }
+        prop = next;
+    }
+}
+
 CalDAVSource::CalDAVSource(const SyncSourceParams &params,
                            const boost::shared_ptr<Neon::Settings> &settings) :
     WebDAVSource(params, settings)
@@ -328,6 +344,10 @@ SubSyncSource::SubItemResult CalDAVSource::insertSubItem(const std::string &luid
          comp = icalcomponent_get_next_component(newEvent->m_calendar, ICAL_VEVENT_COMPONENT)) {
         std::string subid = Event::getSubID(comp);
         EventCache::iterator it;
+        // remove X-SYNCEVOLUTION-EXDATE-DETACHED, could be added by
+        // the engine's read/modify/write cycle when resolving a
+        // conflict
+        removeSyncEvolutionExdateDetached(comp);
         if (!luid.empty() &&
             (it = m_cache.find(luid)) != m_cache.end()) {
             // Additional sanity check: ensure that the expected UID is set.
@@ -736,19 +756,57 @@ void CalDAVSource::readSubItem(const std::string &davLUID, const std::string &su
             icalcomponent_add_component(calendar, clone.release());
         }
         bool found = false;
+        icalcomponent *parent = NULL;
         for (icalcomponent *comp = icalcomponent_get_first_component(event.m_calendar, ICAL_VEVENT_COMPONENT);
              comp;
              comp = icalcomponent_get_next_component(event.m_calendar, ICAL_VEVENT_COMPONENT)) {
             if (Event::getSubID(comp) == subid) {
                 eptr<icalcomponent> clone(icalcomponent_new_clone(comp), "VEVENT");
+                if (subid.empty()) {
+                    parent = clone.get();
+                }
                 icalcomponent_add_component(calendar, clone.release());
                 found = true;
                 break;
             }
         }
+
         if (!found) {
             SE_THROW("event not found");
         }
+
+        // tell engine and peers about EXDATEs implied by
+        // RECURRENCE-IDs in detached recurrences by creating
+        // X-SYNCEVOLUTION-EXDATE-DETACHED in the parent
+        if (parent && event.m_subids.size() > 1) {
+            // remove all old X-SYNCEVOLUTION-EXDATE-DETACHED (just in case)
+            removeSyncEvolutionExdateDetached(parent);
+
+            // now populate with RECURRENCE-IDs of detached recurrences
+            for (icalcomponent *comp = icalcomponent_get_first_component(event.m_calendar, ICAL_VEVENT_COMPONENT);
+                 comp;
+                 comp = icalcomponent_get_next_component(event.m_calendar, ICAL_VEVENT_COMPONENT)) {
+                icalproperty *prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY);
+                if (prop) {
+                    eptr<char> rid(ical_strdup(icalproperty_get_value_as_string(prop)));
+                    icalproperty *exdate = icalproperty_new_from_string(StringPrintf("X-SYNCEVOLUTION-EXDATE-DETACHED:%s", rid.get()).c_str());
+                    if (exdate) {
+                        icalparameter *tzid = icalproperty_get_first_parameter(prop, ICAL_TZID_PARAMETER);
+                        if (tzid) {
+                            icalproperty_add_parameter(exdate, icalparameter_new_clone(tzid));
+                        }
+#if 0
+                        // not needed
+                        if (icalproperty_get_recurrenceid(exdate).is_date) {
+                            icalproperty_add_parameter(exdate, icalparameter_new_value(ICAL_VALUE_DATE));
+                        }
+#endif
+                        icalcomponent_add_property(parent, exdate);
+                    }
+                }
+            }
+        }
+
         eptr<char> icalstr(ical_strdup(icalcomponent_as_ical_string(calendar)));
         item = icalstr.get();
     }
@@ -1157,41 +1215,6 @@ void CalDAVSource::Event::fixIncomingCalendar(icalcomponent *calendar)
             }
         }
     }
-
-    // tell engine and peers about EXDATEs implied by RECURRENCE-IDs
-    // in detached recurrences by creating
-    // X-SYNCEVOLUTION-EXDATE-DETACHED in the parent
-    if (parent) {
-        // remove all old X-SYNCEVOLUTION-EXDATE-DETACHED
-        icalproperty *prop = icalcomponent_get_first_property(parent, ICAL_ANY_PROPERTY);
-        while (prop) {
-            icalproperty *next = icalcomponent_get_next_property(parent, ICAL_ANY_PROPERTY);
-            const char *xname = icalproperty_get_x_name(prop);
-            if (xname &&
-                !strcmp(xname, "X-SYNCEVOLUTION-EXDATE-DETACHED")) {
-                icalcomponent_remove_property(parent, prop);
-                icalproperty_free(prop);
-            }
-            prop = next;
-        }
-        // now populate with RECURRENCE-IDs of detached recurrences
-        for (icalcomponent *comp = icalcomponent_get_first_component(calendar, ICAL_VEVENT_COMPONENT);
-             comp;
-             comp = icalcomponent_get_next_component(calendar, ICAL_VEVENT_COMPONENT)) {
-            icalproperty *prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY);
-            if (prop) {
-                const char *rid = icalproperty_get_value_as_string(prop);
-                icalproperty *exdate = icalproperty_new_from_string(StringPrintf("X-SYNCEVOLUTION-EXDATE-DETACHED:%s", rid).c_str());
-                if (exdate) {
-                    icalparameter *tzid = icalproperty_get_first_parameter(prop, ICAL_TZID_PARAMETER);
-                    if (tzid) {
-                        icalproperty_add_parameter(exdate, icalparameter_new_clone(tzid));
-                    }
-                    icalcomponent_add_property(parent, exdate);
-                }
-            }
-        }
-    }
 }
 
 std::string CalDAVSource::Event::icalTime2Str(const icaltimetype &tt)
